@@ -4,38 +4,74 @@ from .keys import *
 
 _NOTE_WIDTH = 5
 _FRET_WIDTH = 1
-MAX_FRETS = 36
 
-def max_frets_on_screen(limit=24):
+INLAYS = (
+    'I',
+    'II',
+    'III',
+    'IV',
+    'V',
+    'VI',
+    'VII',
+    'VIII',
+    'IX',
+    'X',
+    'XI',
+
+    'XII',
+    'XIII',
+    'XIV',
+    'XV',
+    'XVI',
+    'XVII',
+    'XVIII',
+    'XIX',
+    'XX',
+    'XXI',
+    'XXII',
+    'XXIII',
+
+    'XXIV',
+    'XXV',
+    'XXVI',
+    'XXVII',
+    'XXVIII',
+    'XXIX',
+    'XXX',
+    'XXXI',
+    'XXXII',
+    'XXXIII',
+    'XXXIV',
+    'XXXV',
+    'XXXVI',
+)
+
+MAX_FRETS = len(INLAYS)
+
+def max_frets_on_screen():
+    ''' calculates how may frets can be rendered without exceeding terminal size
+        will NOT go over MAX_FRETS
+    '''
     frets = int(
         tty_cols() / ( _NOTE_WIDTH + _FRET_WIDTH )
     ) - 1
-    return frets if frets <= limit else limit
+    return frets if frets < MAX_FRETS else MAX_FRETS
 
 class PluckedString(object):
 
-    def __init__(self, c, alt='', oct=3, frets=0, display=None, verbose=1):
-        self.tuning = Note(c, alt, oct)
-        self.display_mode = display
-        self.frets = 12 if not frets else frets
+    def __init__(self, c, alt='', oct=3, frets=12, mode=None, verbose=1):
+        self.tuning = MusicNote(c, alt, oct)
+        self.mode = mode
+        self.frets = frets
         self.verbose = verbose
- 
-    @property
-    def frets(self):
-        return self.__frets
-
-    @frets.setter
-    def frets(self, f):
-        self.__frets = int(f) +1
-
 
     def __repr__(self):
         ''' prints string notes matching given key '''
         string_line = Row()
 
-        mode = self.display_mode if self.display_mode else ChromaticScale(*self.tuning)
+        mode = self.mode if self.mode else ChromaticScale(*self.tuning)
 
-        for fret_n, note in enumerate(
+        for f, note in enumerate(
             mode.spell(
                 note_count=self.frets,
                 start_note=self.tuning,
@@ -61,22 +97,22 @@ class PluckedString(object):
             string_line.append(
                 FString(
                     fret_value,
-                    size=_NOTE_WIDTH -1 if fret_n == 0 else _NOTE_WIDTH,
+                    size=_NOTE_WIDTH - 1 if f == 0 else _NOTE_WIDTH,
                     align='cr',
                 )
             )
 
             # APPEND FRET
             string_line.append(
-                FString(                   
-                    '║' if fret_n % 12 == 0 else '│',
+                FString(
+                    '║' if f % 12 == 0 else '│',
                     size=_FRET_WIDTH,
                     # fg='blue',
                     # fx=['faint'],
                 )
             )
 
-            if fret_n == self.frets -1:
+            if f == self.frets:
                 break
 
         return str(string_line)
@@ -90,58 +126,29 @@ class PluckedStringInstrument(object):
         if not verbose:
             return
 
-        inlays = (
-            '',
-            'I' if verbose > 1 else '',
-            'II' if verbose > 1 else '',
-            'III',
-            'IV' if verbose > 1 else '',
-            'V',
-            'VI' if verbose > 1 else '',
-            'VII',
-            'VIII' if verbose > 1 else '',
-            'IX',
-            'X' if verbose > 1 else '',
-            'XI' if verbose > 1 else '',
-
-            'XII',
-            'XIII' if verbose > 1 else '',
-            'XIV' if verbose > 1 else '',
-            'XV',
-            'XVI' if verbose > 1 else '',
-            'XVII',
-            'XVIII' if verbose > 1 else '',
-            'XIX',
-            'XX' if verbose > 1 else '',
-            'XXI',
-            'XXII' if verbose > 1 else '',
-            'XXIII' if verbose > 1 else '',
-
-            'XXIV'
-        )
+        dots = (3, 5, 7, 9, 12, 15, 17, 19, 21, 24, 27, 29, 31, 33, 36)
 
         inlay_row = Row(
             FString(
-                inlays[0],
+                '',
                 size=_NOTE_WIDTH + _FRET_WIDTH,
                 align='l'
             ),
-            size=6 +83 # why this??
         )
 
-        i = 1
+        f = 1
         while frets:
             inlay_row.append(
                 FString(
-                    inlays[i],
+                    '' if verbose == 1 and f not in dots else INLAYS[f-1],
                     size=_NOTE_WIDTH + _FRET_WIDTH,
-                    align='cl',
+                    align='r' if verbose == 2 else 'c', # high verbose needs more space
                     fg='cyan',
-                    fx=['faint' if i in (1, 2, 4, 6, 8, 10, 11, 13, 14, 16, 18, 20, 22, 23) else ''],
+                    fx=['faint' if f not in dots else ''],
                 )
             )
+            f += 1
             frets -= 1
-            i += 1
 
         echo(inlay_row)
 
@@ -157,53 +164,47 @@ class PluckedStringInstrument(object):
         final  = { 'upper': '╕', 'lower': '╛' }
         fine   = { 'upper': '╗', 'lower': '╝' }
         total_fret_width = _NOTE_WIDTH + _FRET_WIDTH
-        fret_bind = ' ' * _NOTE_WIDTH + capo[side]
+        render = ' ' * _NOTE_WIDTH + capo[side]
         for f in range(1, frets * total_fret_width + 1):
             # final fret
             if f == frets * total_fret_width:
                 if f % (total_fret_width * 12) == 0:
-                    fret_bind += fine[side]
+                    render += fine[side]
                 else:
-                    fret_bind += final[side]
+                    render += final[side]
             # 12th, 24th
             elif f % (total_fret_width * 12) == 0:
-                fret_bind += twelve[side]
+                render += twelve[side]
             # fret bar joints
             elif f % total_fret_width == 0:
-                fret_bind += joints[side]
+                render += joints[side]
             # normal bind
             else:
-                fret_bind += normal[side]
-        
-        echo(fret_bind)
+                render += normal[side]
+        echo(render)
 
 
     def __init__(self, *notes, name=''):
         self.strings = [ PluckedString(*n) for n in notes ]
         self.name = name
 
-    def render_string(self, s, display, frets=12, verbose=1):
-        if not s:
-            return
-
+    def render_string(self, s, mode, frets=12, verbose=1):
         string_n = FString(
             s,
-            fg='cyan', 
+            fg='cyan',
             fx=['faint' if verbose < 1 else ''],
         )
-
         string = self.strings[s-1]
-        # INIT A NEW SCALE, OTHERWISE YOU USE THE SAME OUTER OBJECT!!!
-        string.display_mode = display
+        string.mode = mode
         string.frets = frets
         string.verbose = verbose
-
         echo(string_n + string)
 
-    def render_fretboard(self, display=None, frets=12, verbose=1, limit=24):
-        if frets > limit: frets = limit
+    def render_fretboard(self, mode=None, frets=12, verbose=1):
+        # if frets > max_frets_on_screen():
+        #     frets = max_frets_on_screen()
         self.render_inlays(frets, verbose)
         self.render_binding('upper', frets)
         for s, _ in enumerate(self.strings):
-            self.render_string(s+1, display, frets, verbose)
+            self.render_string(s+1, mode, frets, verbose)
         self.render_binding('lower', frets)
